| Title: | Competence-Based Knowledge Space Theory |
|---|---|
| Description: | Competence-based knowledge space theory (CbKST) is an extension of knowledge space theory (KST) modeling the latent skills and competencies underlying the observable response behaviour as described by Heller & Stefanutti (2024) <doi:10.1142/9789811280481_0001>. The package focuses on the mappings between competence and performance ledvel (skill (multi) map, problem function etc.). |
| Authors: | Cord Hockemeyer [aut, cre] |
| Maintainer: | Cord Hockemeyer <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1-0 |
| Built: | 2026-06-30 16:48:03 UTC |
| Source: | https://github.com/cran/CbKST |
cbkst_comp2perf() determines the performance state, i.e. the
subset of items solvable for a person in a given competence state.
cbkst_comp2perf(comp, multimap)cbkst_comp2perf(comp, multimap)
comp |
A binary vector representing the competence state |
multimap |
A data frame of class cbkst_skillmultimap |
A binary vector representing the correspondinng performance state
Other Mapping states:
cbkst_perf2comp(),
cbkst_simple_perf2comp()
cbkst_comp2perf(c(1,1,0,0), exampledata$mu)cbkst_comp2perf(c(1,1,0,0), exampledata$mu)
cbkst_performancestructure() determines the performanxce state, i.e. the
Determine the structure of all skill states producing some perfomrance state
cbkst_competencestructure(multimap, perf = NULL)cbkst_competencestructure(multimap, perf = NULL)
multimap |
A data frame of class cbkst_skillmultimap |
perf |
Optinal performance structure as |
A kmstructure object representing the resulting skill structure
Other Mapping structures:
cbkst_performancestructure()
cbkst_competencestructure(exampledata$mu)cbkst_competencestructure(exampledata$mu)
cbkst_perf2comp() determines competence states underlying a given
performance state under the condition of a skill multimap and optionally
a competence structure.
cbkst_perf2comp(perf, multimap, comp = NULL)cbkst_perf2comp(perf, multimap, comp = NULL)
perf |
A named binary vector representing the performance state |
multimap |
A data frame of class |
comp |
Optional constraining competence structure |
A matrix representing the minimal competence states for item
mastery according to perf
Other Mapping states:
cbkst_comp2perf(),
cbkst_simple_perf2comp()
perf <- c(1,1,1,0,0) names(perf) <- c("z", "y", "x", "w", "v") cbkst_perf2comp(perf, exampledata$multi)perf <- c(1,1,1,0,0) names(perf) <- c("z", "y", "x", "w", "v") cbkst_perf2comp(perf, exampledata$multi)
cbkst_performancestructure() determines the performanxce state, i.e. the
Determine the structure of all performance states reachable from some skill state
cbkst_performancestructure(multimap, comp = NULL)cbkst_performancestructure(multimap, comp = NULL)
multimap |
A data frame of class cbkst_skillmultimap |
comp |
Optinal competence structure as |
A kmstructure object representing the resulting performance structure
Other Mapping structures:
cbkst_competencestructure()
cbkst_performancestructure(exampledata$multi)cbkst_performancestructure(exampledata$multi)
cbkst_simnple_perf2comp() determines competence state underlying a given
performance state under the condition of a skill map.
cbkst_simple_perf2comp(perf, skillmap)cbkst_simple_perf2comp(perf, skillmap)
perf |
A binary vector representing the performance state |
skillmap |
A data frame of class |
A binary vector representing the corresponding competence state
Other Mapping states:
cbkst_comp2perf(),
cbkst_perf2comp()
perf <- c(1,1,1,0,0) names(perf) <- c("z", "y", "x", "w", "v") cbkst_simple_perf2comp(perf, exampledata$mu)perf <- c(1,1,1,0,0) names(perf) <- c("z", "y", "x", "w", "v") cbkst_simple_perf2comp(perf, exampledata$mu)
This small example data set contains a skill map mu, a skill multimap
multi, a competence space cspace, and a performance space
pspace.
exampledataexampledata
List with four elements: mu (skill map), multi (skill
multimap), cspace (competence space), and pspace
(performance space)
read_skillmultimap() reads a skill multimap as data frame.
read_skillmultimap(file)read_skillmultimap(file)
file |
Filename to read |
Data frame of class cbkst_skillmultimap. In case of a
skill map, it also has the class cbkst_skillmap
Data file and resulting data table have the following format: The first
column contains the item and the subsequent rows denote for each skill
if it is contained in .
ODS and XLSX files are recognised.
fpath <- system.file("extdata", "skillmap.ods", package="CbKST") read_skillmultimap(fpath)fpath <- system.file("extdata", "skillmap.ods", package="CbKST") read_skillmultimap(fpath)